@@ -195,7 +195,11 @@ void CrawlerWidget::doSetViewContext(
 
     setSizes( context.sizes() );
     ignoreCaseCheck->setCheckState( context.ignoreCase() ? Qt::Checked : Qt::Unchecked );
-    searchRefreshCheck->setCheckState( context.autoRefresh() ? Qt::Checked : Qt::Unchecked );
+
+    auto auto_refresh_check_state = context.autoRefresh() ? Qt::Checked : Qt::Unchecked;
+    searchRefreshCheck->setCheckState( auto_refresh_check_state );
+    // Manually call the handler as it is not called when changing the state programmatically
+    searchRefreshChangedHandler( auto_refresh_check_state );
 }
 
 std::shared_ptr<const ViewContextInterface>
@@ -346,6 +350,10 @@ void CrawlerWidget::applyConfiguration()
     filteredView->updateDisplaySize();
     filteredView->update();
 
+    // Polling interval
+    logData_->setPollingInterval(
+            config->pollingEnabled() ? config->pollIntervalMs() : 0 );
+
     // Update the SearchLine (history)
     updateSearchCombo();
 }
@@ -521,6 +529,9 @@ void CrawlerWidget::setup()
     overviewWidget_->setOverview( &overview_ );
     overviewWidget_->setParent( logMainView );
 
+    // Connect the search to the top view
+    logMainView->useNewFiltering( logFilteredData_ );
+
     // Construct the visibility button
     visibilityModel_ = new QStandardItemModel( this );
 
@@ -641,6 +652,8 @@ void CrawlerWidget::setup()
     auto config = Persistent<Configuration>( "settings" );
     searchRefreshCheck->setCheckState( config->isSearchAutoRefreshDefault() ?
             Qt::Checked : Qt::Unchecked );
+    // Manually call the handler as it is not called when changing the state programmatically
+    searchRefreshChangedHandler( searchRefreshCheck->checkState() );
     ignoreCaseCheck->setCheckState( config->isSearchIgnoreCaseDefault() ?
             Qt::Checked : Qt::Unchecked );
 
@@ -781,8 +794,6 @@ void CrawlerWidget::replaceCurrentSearch( const QString& searchText )
         searchState_.resetState();
         printSearchInfoMessage();
     }
-    // Connect the search to the top view
-    logMainView->useNewFiltering( logFilteredData_ );
 }
 
 // Updates the content of the drop down list for the saved searches,
